const { chain, toLower } = require('lodash');
const chalk = require('chalk');
const slugify = require('slugify');
const inquirer = require('inquirer');

const { runCommand } = require('../utils');

const MIN_WORD_LENGTH = 3;

const createBranch = async issue => {
  // Create a branch name suggestion
  const branchPrefix = `${toLower(issue.type)}/${issue.id}/`;
  const branchSuffixSuggestion = chain(slugify(issue.summary))
    .toLower()
    .split('-')
    .filter(word => word.length > MIN_WORD_LENGTH)
    .join('-')
    .value();

  // Determine how the branch should be named
  const { branchSuffix } = await inquirer.prompt({
    type: 'input',
    name: 'branchSuffix',
    message: 'What branch name to use?',
    default: branchSuffixSuggestion,
    transformer: input => `\n   ${branchPrefix}${input}`,
  });

  const branchName = `${branchPrefix}${branchSuffix}`;

  // Do create the branch
  console.log(`Creating branch ${chalk.blue(branchName)}...`);
  try {
    const branchCreationOutput = await runCommand(
      `git checkout -b ${branchName}`
    );
    console.log(chalk.dim(branchCreationOutput));
  } catch (error) {
    console.log(chalk.red(error));
  }
};

module.exports = { createBranch };
