const path = require('path');
const fs = require('fs');
const inquirer = require('inquirer');

const configPath = path.resolve(__dirname, `../config.json`);

const DEFAULT_JIRA_FILTER =
  'project+%3D+DATA+AND+status+!%3D+Closed+AND+resolution+%3D+Unresolved+AND+sprint+is+not+EMPTY+AND+assignee+in+(currentUser())+ORDER+BY+originalEstimate+ASC,+updated+DESC';

const createConfig = async () => {
  const { jiraToken, githubToken, user, host, issuesFilter, useEmojis } = await inquirer.prompt([
    {
      type: 'password',
      name: 'githubToken',
      message: 'What is your GitHub Personal Access Token?',
    },
    {
      type: 'password',
      name: 'jiraToken',
      message: 'What is your JIRA API token?',
    },
    {
      type: 'input',
      name: 'user',
      message: 'What is your JIRA username?',
    },
    {
      type: 'input',
      name: 'host',
      message: 'What is your JIRA host?',
      default: 'https://botify.atlassian.net',
    },
    {
      type: 'input',
      name: 'issuesFilter',
      message: 'What is the filter you want to use to retrieve issues?',
      default: DEFAULT_JIRA_FILTER,
    },
    {
      type: 'confirm',
      name: 'useEmojis',
      message: 'Do you want a pretty interface with emojis?',
    }
  ]);

  // Create the config object
  const config = { jiraToken, githubToken, user, host, issuesFilter, useEmojis };

  // Write the config
  const rawConfig = JSON.stringify(config, null, 2);
  fs.writeFileSync(configPath, rawConfig);

  return config;
};

const loadConfig = async () => {
  let config;
  try {
    config = JSON.parse(fs.readFileSync(configPath));
  } catch (error) {
    config = await createConfig();
  }

  return config;
};

module.exports = { loadConfig };
